.. SPDX-FileCopyrightText: 2021 geisserml <geisserml@gmail.com>
.. SPDX-License-Identifier: CC-BY-4.0

Support API
===========

Functions and classes
*********************

.. automodule:: pypdfium2._helpers
    :members:


Constants
*********

.. automodule:: pypdfium2._constants
    :members:


Exceptions
**********

.. automodule:: pypdfium2._exceptions
    :members:
